Gestion de mes Photos - casimages.com
Author: Casimages.com
Description: Simple & Rapide, partagez vos Photos avec Casimages
Keywords: Manager Casimages

Sergeileduc Offre Decouverte

## mes photos

Envoyer des images

- Tout sélectionner
- Supprimer
- Déplacer
- Télécharger
- MultiCode
- Aide

Offre FLASH Offre de stockage à saisir Voir les offres..
Pack-100G-12 - 100 Go d'espace de stockage - 29.90 /an au lieu de 79.90 /an ! - Offre limitée.

# Photos non classées

Envoyer des images

05-11-2005 | 0 images | 0.00 Mo

## Création d'un album

Nom de l'album

## Changer le nom de l'album

Nouveau nom de l'album

## Accès direct privé - Partager l'album

Pour partager le contenu de votre album sans passer par votre galerie photo publique
Ouvrir le lien

## Supprimer un album

#### ATTENTION

Confirmez-vous la suppression de l'album ?

## MultiCode

Service PREMIUM
Pour accéder à ce service, vous devez avoir un compte PREMIUM Casimages.
Devenez PREMIUM à partir de 19.90/an et bénéficiez de 10Go d'espace de stockage. Voir les offres.

## Une question ? Besoin d'aide ?

Comment supprimer, déplacer ou partager mon fichier ?
Pour afficher les options d'un fichier, faites un clic-droit sur le fichier souhaité. Pour obtenir les "codes de partages", cliquez sur Partager dans ce même menu.
Comment supprimer, déplacer ou télécharger (récupérer sur votre ordinateur) plusieurs fichiers à la fois ?
Cliquez sur l'icône située en haut à droite au dessus de vos fichiers. Vous basculerez alors vers le mode listage, permettant d'effectuer des opérations multiples.
Comment modifier l'ordre d'affichage de mes dossiers ou de mes fichiers ?
Rendez-vous dans la section Paramètres puis dans la rubrique Manager Fichiers, puis sélectionner l'ordre de listage des dossiers ou des fichiers
Je souhaite voir le poids ou bien la date d'envoi de mon fichier
Rendez-vous dans la section Paramètres puis dans la rubrique Manager Fichiers, cochez les cases correspondants aux informations que vous souhaitez afficher.
Je rencontre un problème avec le formulaire d'envoi de fichiers
Rendez-vous dans la section Paramètres puis sélectionnez un autre Uploader dans la liste.
Je n'ai pas obtenu de réponse à ma question. Je constate un bug.
Dans ce cas, nous vous invitons à contacter le Support

## Changer le nom de l'image

Nouveau nom de l'image

## Déplacer l'image

Sélectionnez le dossier de destination :

## Partager l'image

## Propriétés de l'image

## Supprimer l'image

#### ATTENTION

Confirmez-vous la suppression de l'image ?

## Corbeille

## Déplacement d'images

#### ATTENTION

Confirmez-vous le déplacement des images ?

## Supprimer la sélection

#### ATTENTION

Confirmez-vous la suppression des éléments sélectionnés ?

## Déplacer la sélection

Sélectionnez le dossier de destination :

## Télécharger la sélection

#### ATTENTION

Confirmez-vous le téléchargement de la sélection ?

## Envoyer des images

Sélectionnez la taille :
5Mo Max par image - 20 images Max par envoi - 100Mo Max pour l'envoi global